==> koffice-1.2.1.tar.bz2: koffice-1.2.1/kword/splitcellsdia.h <==
/* This file is part of the KDE project
   Copyright (C) 2001 Thomas Zander <zander@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef splitcelldia_h
#define splitcelldia_h

#include <kdialogbase.h>
#include <qptrlist.h>

#include "defs.h"

class QGridLayout;
class QLabel;
class QCheckBox;
class QSpinBox;
class KWTablePreview;

class KWSplitCellDia : public KDialogBase {
    Q_OBJECT

public:
    KWSplitCellDia( QWidget *parent, const char *name, unsigned int numrows=1, unsigned int numcols=1);

    unsigned int rows() { return m_rows; }
    unsigned int cols() { return m_cols; }

protected:
    QSpinBox *nRows, *nCols;
    KWTablePreview *preview;

    unsigned int m_rows, m_cols;

protected slots:
    void rowsChanged( int );
    void colsChanged( int );
};

#endif

==> koffice-1.4.1.tar.bz2: koffice-1.4.1/kword/splitcellsdia.h <==
/* This file is part of the KDE project
   Copyright (C) 2001 Thomas Zander <zander@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef splitcelldia_h
#define splitcelldia_h

#include <kdialogbase.h>
#include <qptrlist.h>

#include "defs.h"

class QGridLayout;
class QLabel;
class QCheckBox;
class QSpinBox;
class KWTablePreview;

class KWSplitCellDia : public KDialogBase {
    Q_OBJECT

public:
    KWSplitCellDia( QWidget *parent, const char *name, unsigned int numrows=1, unsigned int numcols=1);

    unsigned int rows()const { return m_rows; }
    unsigned int cols()const { return m_cols; }

protected:
    QSpinBox *nRows, *nCols;
    KWTablePreview *preview;

    unsigned int m_rows, m_cols;

protected slots:
    void rowsChanged( int );
    void colsChanged( int );
};

#endif
